@@ -1,11 +1,10 @@
 package IO::ReadHandle::Include;
 
-use v5.10.0;
+use 5.006;
 use strict;
 use warnings;
 
 use Carp;
-use List::Util qw(none);
 use Path::Class qw(file);
 use Scalar::Util qw(blessed reftype);
 use Symbol qw(gensym);
@@ -19,11 +18,11 @@ facility
 
 =head1 VERSION
 
-Version 1.2.1
+Version 1.1
 
 =cut
 
-use version; our $VERSION = version->declare('v1.2.1');
+use version; our $VERSION = version->declare('v1.1');
 
 =head1 SYNOPSIS
 
@@ -77,12 +76,6 @@ included file can itself include other files, using the same format
 for include directives.  If an include file does not exist, then the
 include directive naming that file is not replaced.
 
-An include file cannot recursively include itself, because that leads
-to an infinite loop.  If such an include directive detected, then it
-is not replaced.  It is not a problem if a particular file is included
-multiple times, as long as each next include of that file begins after
-the previous include has completed.
-
 The include file is identified by the text corresponding to a
 particular capture group (C<< (?<include>...) >> or C<$1>) of the
 regular expression.  For example, given the two lines of text
@@ -158,7 +151,7 @@ cannot apply to any include directives that were resolved while
 processing the L</read> call that produced the text that indicates the
 need to change the transformation.
 
-In such a case, use the L</set_read_by_line> method to indicate that
+In such a case, use the L</set_read_by_lines> method to indicate that
 you want L</read> to return text that does not extend beyond the first
 input record separator -- i.e., at most one line of text.  You may
 then get fewer characters from a call to L</read> than you asked for,
@@ -290,8 +283,7 @@ sub CLOSE {
   # close any included files
   1 while $self->_end_include;
 
-  my $ms = $self->_get('main_source');
-  if ( defined( $ms ) && ( reftype( $ms ) // '' ) eq '' ) {
+  if ( reftype( $self->_get('main_source') ) eq '' ) {
 
     # the main source was passed as a scalar, so we opened its
     # filehandle
@@ -492,22 +484,19 @@ sub READLINE {
         # including file
         $path = file( file( $self->_get('source') )->parent, $path );
       }
-      # avoid infinite recursion
-      my $sources = $self->_get('sources');
-      if ( none { $_ eq $path } @{ $sources } ) {
-        if ( CORE::open my $newifh, '<', "$path" ) {
-          my $suffix = substr( $line, $+[0] ); # text beyond the regex match
-          push @{ $self->_get('suffixes') }, $suffix; # save for later
+      if ( CORE::open my $newifh, '<', "$path" ) {
+        my $suffix = substr( $line, $+[0] );    # text beyond the regex match
+        push @{ $self->_get('suffixes') }, $suffix;    # save for later
 
-          push @{ $self->_get('ifhs') }, $self->_get('ifh'); # save for later
-          push @{ $sources }, $self->_get('source'); # save for later
+        push @{ $self->_get('ifhs') }, $self->_get('ifh');    # save for later
+        push @{ $self->_get('sources') },
+          $self->_get('source');                              # save for later
 
-          $self->_set( ifh => $newifh ) # current source is included file
-            ->_set( source => $path );  # current source
-          $line = substr( $line, 0, $-[0] ) # text before the regex match
-            . $self->READLINE;  # append first line from included file
-        }                       # otherwise we leave the original text
-      }
+        $self->_set( ifh => $newifh )    # current source is included file
+          ->_set( source => $path );     # current source
+        $line = substr( $line, 0, $-[0] )    # text before the regex match
+          . $self->READLINE;    # append first line from included file
+      }    # otherwise we leave the original text
     }
     return $line;
   }
@@ -562,8 +551,7 @@ sub open {
     or reftype($regex) ne 'REGEXP';
   croak "Transform, if set, must be a code reference"
     if $coderef and reftype($coderef) ne 'CODE';
-  $self->_set( source => file($source)->absolute )
-    ->_set( main_source => $source )
+  $self->_set( source => $source )->_set( main_source => $source )
     ->_set( include => $regex )->_set( transform => $coderef );
   return $self;
 }
@@ -624,7 +612,7 @@ into the C<$buffer> at offset C<$offset>, similar to the
 L<CORE::read|perlfunc/read> function.  Returns the number of
 characters read, or 0 when there are no more characters.
 
-If L</set_read_by_line> is active, then the reading stops after the
+If L</set_read_by_lines> is active, then the reading stops after the
 first encountered input record separator (L<$E<sol>|perlvar/"$/">),
 even if the requested number of characters has not been reached yet.
 
@@ -867,7 +855,7 @@ position, or the very end of the stream.
 
 =item
 
-L<tell> cannot be used on an B<IO::ReadHandle::Include>.
+L</tell> cannot be used on an B<IO::ReadHandle::Include>.
 
 =back
 
